package org.apache.commons.lang3.function;

import java.lang.Throwable;
import java.util.Objects;

@FunctionalInterface
/* loaded from: org_apache_commons_lang3_function.jar:org/apache/commons/lang3/function/FailableIntPredicate.class */
public interface FailableIntPredicate<E extends Throwable> {
    public static final FailableIntPredicate FALSE = t -> {
        return false;
    };
    public static final FailableIntPredicate TRUE = t -> {
        return true;
    };

    boolean test(int i) throws Throwable;

    static <E extends Throwable> FailableIntPredicate<E> falsePredicate() {
        return FALSE;
    }

    static <E extends Throwable> FailableIntPredicate<E> truePredicate() {
        return TRUE;
    }

    default FailableIntPredicate<E> and(FailableIntPredicate<E> other) {
        Objects.requireNonNull(other);
        return t -> {
            return test(t) && other.test(t);
        };
    }

    default FailableIntPredicate<E> negate() {
        return t -> {
            return !test(t);
        };
    }

    default FailableIntPredicate<E> or(FailableIntPredicate<E> other) {
        Objects.requireNonNull(other);
        return t -> {
            return test(t) || other.test(t);
        };
    }
}
